@@ -6,7 +6,7 @@ use strict;
 use Exporter;
 use base 'Exporter';
 
-our $VERSION = "2.005";
+our $VERSION = "2.006";
 
 our @ARGV_CLEAN;
 our @EXPORT = qw(@ARGV_CLEAN);
@@ -203,6 +203,14 @@ sub new {
 	my $self = bless _stage2($c);
 }
 
+=head2 argv()
+
+Returns the @ARGV_CLEAN list
+
+=cut
+
+sub argv { return @ARGV_CLEAN; }
+
 =head2 value(SECTION, KEY)
 
 Retrieve a configuration value or list from B<SECTION> for B<KEY> keyname.
